==> spip_4.0.4.orig.tar.xz: plugins-dist/medias/lib/mejs/lang/sv.js <==
'use strict';/*!
 * This is a `i18n` language object.
 *
 * Swedish
 *
 * @author
 *   Petter (Twitter: @petter_j)
 *
 * @see core/i18n.js
 */
(function (exports) {
	if (exports.sv === undefined) {
		exports.sv = {
			'mejs.plural-form': 1,			
			'mejs.download-file': 'Ladda ner fil',			
			'mejs.install-flash': 'Du använder en webbläsare som inte har Flash Player aktiverat eller installerad. Aktivera Flash Player eller hämta den senaste versionen från https://get.adobe.com/flashplayer/',			
			'mejs.fullscreen': 'Fullskärm',			
			'mejs.play': 'Spela',
			'mejs.pause': 'Pausa',			
			'mejs.time-slider': 'Tidslinje',
			'mejs.time-help-text': 'Använd Vänster/Höger piltangent för att spola en sekund, Upp/Ner piltangent spola tio sekunder.',
			'mejs.live-broadcast': 'Livesändning',			
			'mejs.volume-help-text': 'Använd Upp/Ner piltangent för att öka eller minska volymen.',
			'mejs.unmute': 'Ljud på',
			'mejs.mute': 'Ljud av',
			'mejs.volume-slider': 'Volymkontroll',			
			'mejs.video-player': 'Videospelare',
			'mejs.audio-player': 'Ljudspelare',			
			'mejs.captions-subtitles': 'Textning/Undertexter',
			'mejs.captions-chapters': 'Kapitel',
			'mejs.none': 'Ingen',
			'mejs.afrikaans': 'Afrikaans',
			'mejs.albanian': 'Albanska',
			'mejs.arabic': 'Arabiska',
			'mejs.belarusian': 'Nederländska',
			'mejs.bulgarian': 'Bulgariska',
			'mejs.catalan': 'Katalanska',
			'mejs.chinese': 'Kinesiska',
			'mejs.chinese-simplified': 'Kinesiska (Förenklad)',
			'mejs.chinese-traditional': 'Kinesiska (Traditionell)',
			'mejs.croatian': 'Kroatiska',
			'mejs.czech': 'Tjeckiska',
			'mejs.danish': 'Danska',
			'mejs.dutch': 'Holländska',
			'mejs.english': 'Engelska',
			'mejs.estonian': 'Estniska',
			'mejs.filipino': 'Filipinska',
			'mejs.finnish': 'Finska',
			'mejs.french': 'Franska',
			'mejs.galician': 'Galiciska',
			'mejs.german': 'Tyska',
			'mejs.greek': 'Grekiska',
			'mejs.haitian-creole': 'Haitisk kreolsk',
			'mejs.hebrew': 'Hebreiska',
			'mejs.hindi': 'Hindi',
			'mejs.hungarian': 'Ungerska',
			'mejs.icelandic': 'Isländska',
			'mejs.indonesian': 'Indonesiska',
			'mejs.irish': 'Irländska',
			'mejs.italian': 'Italienska',
			'mejs.japanese': 'Japanska',
			'mejs.korean': 'Koreanska',
			'mejs.latvian': 'Lettiska',
			'mejs.lithuanian': 'Litauiska',
			'mejs.macedonian': 'Makedonska',
			'mejs.malay': 'Malaysiska',
			'mejs.maltese': 'Maltesiska',
			'mejs.norwegian': 'Norska',
			'mejs.persian': 'Persiska',
			'mejs.polish': 'Polska',
			'mejs.portuguese': 'Portugisiska',
			'mejs.romanian': 'Romänska',
			'mejs.russian': 'Ryska',
			'mejs.serbian': 'Serbiska',
			'mejs.slovak': 'Slovakiska',
			'mejs.slovenian': 'Slovenska',
			'mejs.spanish': 'Spanska',
			'mejs.swahili': 'Swahiliska',
			'mejs.swedish': 'Svenska',
			'mejs.tagalog': 'Tagalogiska',
			'mejs.thai': 'Thailänska',
			'mejs.turkish': 'Turkiska',
			'mejs.ukrainian': 'Ukrainska',
			'mejs.vietnamese': 'Vietnamesiska',
			'mejs.welsh': 'Skotska',
			'mejs.yiddish': 'Jiddisch'
		};
	}
})(mejs.i18n);

==> spip_4.4.3+dfsg.orig.tar.xz: plugins-dist/medias/lib/mejs/lang/sv.js <==
/*!
 * This is a `i18n` language object.
 *
 * Swedish
 *
 * @author
 *   Petter (Twitter: @petter_j)
 *
 * @see core/i18n.js
 */
(function (exports) {
    'use strict';	if (exports.sv === undefined) {
		exports.sv = {
			'mejs.plural-form': 1,			
			'mejs.download-file': 'Ladda ner fil',			
			'mejs.fullscreen': 'Fullskärm',			
			'mejs.play': 'Spela',
			'mejs.pause': 'Pausa',			
			'mejs.time-slider': 'Tidslinje',
			'mejs.time-help-text': 'Använd Vänster/Höger piltangent för att spola en sekund, Upp/Ner piltangent spola tio sekunder.',
			'mejs.live-broadcast': 'Livesändning',			
			'mejs.volume-help-text': 'Använd Upp/Ner piltangent för att öka eller minska volymen.',
			'mejs.unmute': 'Ljud på',
			'mejs.mute': 'Ljud av',
			'mejs.volume-slider': 'Volymkontroll',			
			'mejs.video-player': 'Videospelare',
			'mejs.audio-player': 'Ljudspelare',			
			'mejs.captions-subtitles': 'Textning/Undertexter',
			'mejs.captions-chapters': 'Kapitel',
			'mejs.none': 'Ingen',
			'mejs.afrikaans': 'Afrikaans',
			'mejs.albanian': 'Albanska',
			'mejs.arabic': 'Arabiska',
			'mejs.belarusian': 'Nederländska',
			'mejs.bulgarian': 'Bulgariska',
			'mejs.catalan': 'Katalanska',
			'mejs.chinese': 'Kinesiska',
			'mejs.chinese-simplified': 'Kinesiska (Förenklad)',
			'mejs.chinese-traditional': 'Kinesiska (Traditionell)',
			'mejs.croatian': 'Kroatiska',
			'mejs.czech': 'Tjeckiska',
			'mejs.danish': 'Danska',
			'mejs.dutch': 'Holländska',
			'mejs.english': 'Engelska',
			'mejs.estonian': 'Estniska',
			'mejs.filipino': 'Filipinska',
			'mejs.finnish': 'Finska',
			'mejs.french': 'Franska',
			'mejs.galician': 'Galiciska',
			'mejs.german': 'Tyska',
			'mejs.greek': 'Grekiska',
			'mejs.haitian-creole': 'Haitisk kreolsk',
			'mejs.hebrew': 'Hebreiska',
			'mejs.hindi': 'Hindi',
			'mejs.hungarian': 'Ungerska',
			'mejs.icelandic': 'Isländska',
			'mejs.indonesian': 'Indonesiska',
			'mejs.irish': 'Irländska',
			'mejs.italian': 'Italienska',
			'mejs.japanese': 'Japanska',
			'mejs.korean': 'Koreanska',
			'mejs.latvian': 'Lettiska',
			'mejs.lithuanian': 'Litauiska',
			'mejs.macedonian': 'Makedonska',
			'mejs.malay': 'Malaysiska',
			'mejs.maltese': 'Maltesiska',
			'mejs.norwegian': 'Norska',
			'mejs.persian': 'Persiska',
			'mejs.polish': 'Polska',
			'mejs.portuguese': 'Portugisiska',
			'mejs.romanian': 'Romänska',
			'mejs.russian': 'Ryska',
			'mejs.serbian': 'Serbiska',
			'mejs.slovak': 'Slovakiska',
			'mejs.slovenian': 'Slovenska',
			'mejs.spanish': 'Spanska',
			'mejs.swahili': 'Swahiliska',
			'mejs.swedish': 'Svenska',
			'mejs.tagalog': 'Tagalogiska',
			'mejs.thai': 'Thailänska',
			'mejs.turkish': 'Turkiska',
			'mejs.ukrainian': 'Ukrainska',
			'mejs.vietnamese': 'Vietnamesiska',
			'mejs.welsh': 'Skotska',
			'mejs.yiddish': 'Jiddisch'
		};
	}
})(mejs.i18n);
